==> request-tracker4_4.4.4+dfsg.orig-third-party-source.tar.gz: rt-4.4.4/devel/third-party/ckeditor-src/plugins/link/lang/mn.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'mn', {
	acccessKey: 'Холбох түлхүүр',
	advanced: 'Нэмэлт',
	advisoryContentType: 'Зөвлөлдөх төрлийн агуулга',
	advisoryTitle: 'Зөвлөлдөх гарчиг',
	anchor: {
		toolbar: 'Зангуу',
		menu: 'Зангууг болосруулах',
		title: 'Зангуугийн шинж чанар',
		name: 'Зангуугийн нэр',
		errorName: 'Зангуугийн нэрийг оруулна уу',
		remove: 'Зангууг устгах'
	},
	anchorId: 'Элемэнтйн Id нэрээр',
	anchorName: 'Зангуугийн нэрээр',
	charset: 'Тэмдэгт оноох нөөцөд холбогдсон',
	cssClasses: 'Stylesheet классууд',
	emailAddress: 'Э-шуудангийн хаяг',
	emailBody: 'Зурвасны их бие',
	emailSubject: 'Зурвасны гарчиг',
	id: 'Id',
	info: 'Холбоосын тухай мэдээлэл',
	langCode: 'Хэлний код',
	langDir: 'Хэлний чиглэл',
	langDirLTR: 'Зүүнээс баруун (LTR)',
	langDirRTL: 'Баруунаас зүүн (RTL)',
	menu: 'Холбоос засварлах',
	name: 'Нэр',
	noAnchors: '(Баримт бичиг зангуугүй байна)',
	noEmail: 'Э-шуудангий хаягаа шивнэ үү',
	noUrl: 'Холбоосны URL хаягийг шивнэ үү',
	other: '<other>', // MISSING
	popupDependent: 'Хамаатай (Netscape)',
	popupFeatures: 'Popup цонхны онцлог',
	popupFullScreen: 'Цонх дүүргэх (Internet Explorer)',
	popupLeft: 'Зүүн байрлал',
	popupLocationBar: 'Location хэсэг',
	popupMenuBar: 'Цэсний самбар',
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Скрол хэсэгүүд',
	popupStatusBar: 'Статус хэсэг',
	popupToolbar: 'Багажны самбар',
	popupTop: 'Дээд байрлал',
	rel: 'Relationship', // MISSING
	selectAnchor: 'Нэг зангууг сонгоно уу',
	styles: 'Загвар',
	tabIndex: 'Tab индекс',
	target: 'Байрлал',
	targetFrame: '<Агуулах хүрээ>',
	targetFrameName: 'Очих фремын нэр',
	targetPopup: '<popup цонх>',
	targetPopupName: 'Popup цонхны нэр',
	title: 'Холбоос',
	toAnchor: 'Энэ бичвэр дэх зангуу руу очих холбоос',
	toEmail: 'Э-захиа',
	toUrl: 'цахим хуудасны хаяг (URL)',
	toolbar: 'Холбоос',
	type: 'Линкийн төрөл',
	unlink: 'Холбоос авч хаях',
	upload: 'Хуулах'
} );

==> request-tracker5_5.0.1+dfsg.orig-third-party-source.tar.gz: rt-5.0.1/devel/third-party/ckeditor-src/plugins/link/lang/mn.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'mn', {
	acccessKey: 'Холбох түлхүүр',
	advanced: 'Нэмэлт',
	advisoryContentType: 'Зөвлөлдөх төрлийн агуулга',
	advisoryTitle: 'Зөвлөлдөх гарчиг',
	anchor: {
		toolbar: 'Зангуу',
		menu: 'Зангууг болосруулах',
		title: 'Зангуугийн шинж чанар',
		name: 'Зангуугийн нэр',
		errorName: 'Зангуугийн нэрийг оруулна уу',
		remove: 'Зангууг устгах'
	},
	anchorId: 'Элемэнтйн Id нэрээр',
	anchorName: 'Зангуугийн нэрээр',
	charset: 'Тэмдэгт оноох нөөцөд холбогдсон',
	cssClasses: 'Stylesheet классууд',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Э-шуудангийн хаяг',
	emailBody: 'Зурвасны их бие',
	emailSubject: 'Зурвасны гарчиг',
	id: 'Id',
	info: 'Холбоосын тухай мэдээлэл',
	langCode: 'Хэлний код',
	langDir: 'Хэлний чиглэл',
	langDirLTR: 'Зүүнээс баруун (LTR)',
	langDirRTL: 'Баруунаас зүүн (RTL)',
	menu: 'Холбоос засварлах',
	name: 'Нэр',
	noAnchors: '(Баримт бичиг зангуугүй байна)',
	noEmail: 'Э-шуудангий хаягаа шивнэ үү',
	noUrl: 'Холбоосны URL хаягийг шивнэ үү',
	noTel: 'Please type the phone number', // MISSING
	other: '<other>', // MISSING
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Хамаатай (Netscape)',
	popupFeatures: 'Popup цонхны онцлог',
	popupFullScreen: 'Цонх дүүргэх (Internet Explorer)',
	popupLeft: 'Зүүн байрлал',
	popupLocationBar: 'Location хэсэг',
	popupMenuBar: 'Цэсний самбар',
	popupResizable: 'Resizable', // MISSING
	popupScrollBars: 'Скрол хэсэгүүд',
	popupStatusBar: 'Статус хэсэг',
	popupToolbar: 'Багажны самбар',
	popupTop: 'Дээд байрлал',
	rel: 'Relationship', // MISSING
	selectAnchor: 'Нэг зангууг сонгоно уу',
	styles: 'Загвар',
	tabIndex: 'Tab индекс',
	target: 'Байрлал',
	targetFrame: '<Агуулах хүрээ>',
	targetFrameName: 'Очих фремын нэр',
	targetPopup: '<popup цонх>',
	targetPopupName: 'Popup цонхны нэр',
	title: 'Холбоос',
	toAnchor: 'Энэ бичвэр дэх зангуу руу очих холбоос',
	toEmail: 'Э-захиа',
	toUrl: 'цахим хуудасны хаяг (URL)',
	toPhone: 'Phone', // MISSING
	toolbar: 'Холбоос',
	type: 'Линкийн төрөл',
	unlink: 'Холбоос авч хаях',
	upload: 'Хуулах'
} );
